database Package
================

:mod:`database` Package
-----------------------

.. automodule:: stoqlib.database
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`admin` Module
-------------------

.. automodule:: stoqlib.database.admin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`exceptions` Module
------------------------

.. automodule:: stoqlib.database.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`expr` Module
-----------------

.. automodule:: stoqlib.database.expr
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`interfaces` Module
------------------------

.. automodule:: stoqlib.database.interfaces
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`migration` Module
-----------------------

.. automodule:: stoqlib.database.migration
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`orm` Module
-----------------

.. automodule:: stoqlib.database.orm
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`policy` Module
--------------------

.. automodule:: stoqlib.database.policy
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`runtime` Module
---------------------

.. automodule:: stoqlib.database.runtime
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`settings` Module
----------------------

.. automodule:: stoqlib.database.settings
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`tables` Module
--------------------

.. automodule:: stoqlib.database.tables
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`testsuite` Module
-----------------------

.. automodule:: stoqlib.database.testsuite
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`viewable` Module
-----------------

.. automodule:: stoqlib.database.viewable
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    stoqlib.database.test

